@@ -49,6 +49,7 @@ from .type_defs import (
     GetChannelMessageResponseTypeDef,
     GetChannelMessageStatusResponseTypeDef,
     GetMessagingSessionEndpointResponseTypeDef,
+    GetMessagingStreamingConfigurationsResponseTypeDef,
     ListChannelBansResponseTypeDef,
     ListChannelFlowsResponseTypeDef,
     ListChannelMembershipsForAppInstanceUserResponseTypeDef,
@@ -64,10 +65,12 @@ from .type_defs import (
     ProcessorTypeDef,
     PushNotificationConfigurationTypeDef,
     PutChannelMembershipPreferencesResponseTypeDef,
+    PutMessagingStreamingConfigurationsResponseTypeDef,
     RedactChannelMessageResponseTypeDef,
     SearchChannelsResponseTypeDef,
     SearchFieldTypeDef,
     SendChannelMessageResponseTypeDef,
+    StreamingConfigurationTypeDef,
     TagTypeDef,
     UpdateChannelFlowResponseTypeDef,
     UpdateChannelMessageResponseTypeDef,
@@ -307,6 +310,16 @@ class ChimeSDKMessagingClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client/#delete_channel_moderator)
         """
 
+    def delete_messaging_streaming_configurations(
+        self, *, AppInstanceArn: str
+    ) -> EmptyResponseMetadataTypeDef:
+        """
+        Deletes the streaming configurations for an `AppInstance`.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.delete_messaging_streaming_configurations)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client/#delete_messaging_streaming_configurations)
+        """
+
     def describe_channel(
         self, *, ChannelArn: str, ChimeBearer: str
     ) -> DescribeChannelResponseTypeDef:
@@ -440,6 +453,16 @@ class ChimeSDKMessagingClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client/#get_messaging_session_endpoint)
         """
 
+    def get_messaging_streaming_configurations(
+        self, *, AppInstanceArn: str
+    ) -> GetMessagingStreamingConfigurationsResponseTypeDef:
+        """
+        Retrieves the data streaming configuration for an `AppInstance`.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.get_messaging_streaming_configurations)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client/#get_messaging_streaming_configurations)
+        """
+
     def list_channel_bans(
         self, *, ChannelArn: str, ChimeBearer: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListChannelBansResponseTypeDef:
@@ -596,6 +619,19 @@ class ChimeSDKMessagingClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client/#put_channel_membership_preferences)
         """
 
+    def put_messaging_streaming_configurations(
+        self,
+        *,
+        AppInstanceArn: str,
+        StreamingConfigurations: Sequence[StreamingConfigurationTypeDef]
+    ) -> PutMessagingStreamingConfigurationsResponseTypeDef:
+        """
+        Sets the data streaming configuration for an `AppInstance`.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.put_messaging_streaming_configurations)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client/#put_messaging_streaming_configurations)
+        """
+
     def redact_channel_message(
         self, *, ChannelArn: str, MessageId: str, ChimeBearer: str, SubChannelId: str = ...
     ) -> RedactChannelMessageResponseTypeDef:
