@@ -25,6 +25,7 @@ from .literals import (
     ChannelPrivacyType,
     ErrorCodeType,
     FallbackActionType,
+    MessagingDataTypeType,
     PushNotificationTypeType,
     SearchFieldOperatorType,
     SortOrderType,
@@ -64,6 +65,7 @@ __all__ = (
     "DeleteChannelMessageRequestRequestTypeDef",
     "DeleteChannelModeratorRequestRequestTypeDef",
     "DeleteChannelRequestRequestTypeDef",
+    "DeleteMessagingStreamingConfigurationsRequestRequestTypeDef",
     "DescribeChannelBanRequestRequestTypeDef",
     "DescribeChannelFlowRequestRequestTypeDef",
     "DescribeChannelMembershipForAppInstanceUserRequestRequestTypeDef",
@@ -76,6 +78,8 @@ __all__ = (
     "GetChannelMessageRequestRequestTypeDef",
     "GetChannelMessageStatusRequestRequestTypeDef",
     "MessagingSessionEndpointTypeDef",
+    "GetMessagingStreamingConfigurationsRequestRequestTypeDef",
+    "StreamingConfigurationTypeDef",
     "LambdaConfigurationTypeDef",
     "ListChannelBansRequestRequestTypeDef",
     "ListChannelFlowsRequestRequestTypeDef",
@@ -131,6 +135,9 @@ __all__ = (
     "ListTagsForResourceResponseTypeDef",
     "TagResourceRequestRequestTypeDef",
     "GetMessagingSessionEndpointResponseTypeDef",
+    "GetMessagingStreamingConfigurationsResponseTypeDef",
+    "PutMessagingStreamingConfigurationsRequestRequestTypeDef",
+    "PutMessagingStreamingConfigurationsResponseTypeDef",
     "ProcessorConfigurationTypeDef",
     "ListSubChannelsResponseTypeDef",
     "SearchChannelsRequestRequestTypeDef",
@@ -463,6 +470,13 @@ class DeleteChannelRequestRequestTypeDef(
     pass
 
 
+DeleteMessagingStreamingConfigurationsRequestRequestTypeDef = TypedDict(
+    "DeleteMessagingStreamingConfigurationsRequestRequestTypeDef",
+    {
+        "AppInstanceArn": str,
+    },
+)
+
 DescribeChannelBanRequestRequestTypeDef = TypedDict(
     "DescribeChannelBanRequestRequestTypeDef",
     {
@@ -611,6 +625,21 @@ MessagingSessionEndpointTypeDef = TypedDict(
     total=False,
 )
 
+GetMessagingStreamingConfigurationsRequestRequestTypeDef = TypedDict(
+    "GetMessagingStreamingConfigurationsRequestRequestTypeDef",
+    {
+        "AppInstanceArn": str,
+    },
+)
+
+StreamingConfigurationTypeDef = TypedDict(
+    "StreamingConfigurationTypeDef",
+    {
+        "DataType": MessagingDataTypeType,
+        "ResourceArn": str,
+    },
+)
+
 LambdaConfigurationTypeDef = TypedDict(
     "LambdaConfigurationTypeDef",
     {
@@ -1406,6 +1435,30 @@ GetMessagingSessionEndpointResponseTypeDef = TypedDict(
     },
 )
 
+GetMessagingStreamingConfigurationsResponseTypeDef = TypedDict(
+    "GetMessagingStreamingConfigurationsResponseTypeDef",
+    {
+        "StreamingConfigurations": List[StreamingConfigurationTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+PutMessagingStreamingConfigurationsRequestRequestTypeDef = TypedDict(
+    "PutMessagingStreamingConfigurationsRequestRequestTypeDef",
+    {
+        "AppInstanceArn": str,
+        "StreamingConfigurations": Sequence[StreamingConfigurationTypeDef],
+    },
+)
+
+PutMessagingStreamingConfigurationsResponseTypeDef = TypedDict(
+    "PutMessagingStreamingConfigurationsResponseTypeDef",
+    {
+        "StreamingConfigurations": List[StreamingConfigurationTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 ProcessorConfigurationTypeDef = TypedDict(
     "ProcessorConfigurationTypeDef",
     {
